@@ -10,7 +10,7 @@ import requests
 import yaml
 import time
 
-VERSION = '0.1.2'
+VERSION = '0.1.3'
 
 default_backliftURL = 'http://backlift.com/'
 backlift_configfile = '.backlift'
@@ -248,7 +248,7 @@ def register(key):
 def create(path, name='', template='blank'):
 
     # import pdb; pdb.set_trace()
-    
+
     app_root = os.path.normpath(
                     os.path.abspath(
                         os.path.join(path, name)))
@@ -264,6 +264,10 @@ def create(path, name='', template='blank'):
             'app_id': id
         })
 
+        if not name: name='current'
+        print "A new app has been created in the %s folder." % name
+        print "This app will be called %s." % id
+
     else:
         fail(ERR_BADID)
 
@@ -330,8 +334,8 @@ def execute_command_line():
     usagetxt = '%prog COMMAND [options]\n\n' +\
         'Commands:\n' +\
         '  register KEY\t\tRegister this computer for early access\n' +\
-        '  create NAME\t\tCreate a new basic backlift app\n' +\
-        '  create:TYPE NAME\t\tCreate a new backlift app using the TYPE template\n' +\
+        '  create NAME\t\tCreate a new basic backlift app in the NAME folder\n' +\
+        '  create:TYPE NAME\tCreate a new backlift app using the TYPE template\n' +\
         '  init\t\t\tInitialize backlift for an existing app\n' +\
         '  push\t\t\tPush files up to backlift\n' +\
         '  watch\t\t\tObserve path and push files to backlift whenever they change'
